#[unsafe(link_section = ".iram1.interrupt_active")]pub fn active() -> boolExpand description
Returns true if the currently active core is executing an ISR request
#[unsafe(link_section = ".iram1.interrupt_active")]pub fn active() -> boolReturns true if the currently active core is executing an ISR request