pub struct IsrCriticalSectionGuard<'a>(/* private fields */);Trait Implementations
Sourceimpl Drop for IsrCriticalSectionGuard<'_>
impl Drop for IsrCriticalSectionGuard<'_>
Sourcefn drop(&mut self)
fn drop(&mut self)
Drops the critical section guard thus potentially re-enabling al interrupts for the currently active core.
Note that - due to the fact that calling IsrCriticalSection::enter
multiple times on the same or multiple critical sections is supported -
interrupts for the core will be re-enabled only when the last guard that
disabled interrupts for the concrete core is dropped.
fn pin_drop(self: Pin<&mut Self>)
fn pin_drop(self: Pin<&mut Self>)
🔬This is a nightly-only experimental API. (
pin_ergonomics)Execute the destructor for this type, but different to
Drop::drop, it requires self
to be pinned. Read more